#
# This file is part of LiteScope.
#
# Copyright (c) 2017 Florent Kermarrec <florent@enjoy-digital.fr>
# SPDX-License-Identifier: BSD-2-Clause

import unittest
import os
from math import cos, sin

from litescope.software.dump import *

#TODO:
# - find a way to check if files are generated correctly

dump = Dump()
for i in range(4):
    dump.add(DumpVariable("ramp"+str(i), 2**i, [j for j in range(256)]))
pi = 3.1415
dump.add(DumpVariable("sin", 8, [128+128*sin(j/(2*pi*16)) for j in range(1024)]))
dump.add(DumpVariable("cos", 8, [128+128*cos(j/(2*pi*16)) for j in range(1024)]))


class TestDump(unittest.TestCase):
    def test_csv(self):
        filename = "dump.csv"
        CSVDump(dump).write(filename)
        os.remove(filename)

    def test_py(self):
        filename = "dump.py"
        PythonDump(dump).write(filename)
        os.remove(filename)

    def test_sigrok(self):
        filename = "dump.sr"
        SigrokDump(dump).write(filename)
        SigrokDump(dump).read(filename)
        SigrokDump(dump).write(filename)
        os.remove(filename)

    def test_vcd(self):
        filename = "dump.vcd"
        VCDDump(dump).write(filename)
        os.remove(filename)



#
# This file is part of LiteScope.
#
# Copyright (c) 2019 Florent Kermarrec <florent@enjoy-digital.fr>
# SPDX-License-Identifier: BSD-2-Clause

import unittest
import os

from litescope.software.dump import *

root_dir    = os.path.join(os.path.abspath(os.path.dirname(__file__)), "..")

class TestExamples(unittest.TestCase):
    def test_arty(self):
        os.system(f"rm -rf {root_dir}/build")
        os.system(f"cd {root_dir}/examples && python3 arty.py")
        self.assertEqual(os.path.isfile(f"{root_dir}/examples/build/digilent_arty/gateware/digilent_arty.v"), True)



#
# This file is part of LiteScope.
#
# Copyright (c) 2017-2019 Florent Kermarrec <florent@enjoy-digital.fr>
# SPDX-License-Identifier: BSD-2-Clause

import unittest

from migen import *

from litescope import LiteScopeAnalyzer


class TestAnalyzer(unittest.TestCase):
    def test_analyzer(self):
        def generator(dut):
            dut.data = []
            # Configure Trigger
            yield from dut.analyzer.trigger.mem_value.write(0x0010)
            yield from dut.analyzer.trigger.mem_mask.write(0xffff)
            yield from dut.analyzer.trigger.mem_write.write(1)

            # Configure Subsampler
            yield from dut.analyzer.subsampler.value.write(2)

            # Configure Storage
            yield from dut.analyzer.storage.length.write(256)
            yield from dut.analyzer.storage.offset.write(8)
            yield from dut.analyzer.storage.enable.write(1)
            yield
            for i in range(16):
                yield
            # Wait capture
            while not (yield from dut.analyzer.storage.done.read()):
                yield
            # Read captured datas
            while (yield from dut.analyzer.storage.mem_level.read()) > 0:
                dut.data.append((yield from dut.analyzer.storage.mem_data.read()))
                yield

        class DUT(Module):
            def __init__(self):
                counter = Signal(32)
                self.sync += counter.eq(counter + 1)
                self.submodules.analyzer = LiteScopeAnalyzer(counter, 512)

        dut = DUT()
        generators = {"sys" : [generator(dut)]}
        clocks     = {"sys": 10, "scope": 10}
        run_simulation(dut, generators, clocks, vcd_name="sim.vcd")
        self.assertEqual(dut.data, [524 + 3*i for i in range(len(dut.data))])



#!/usr/bin/env python3

from setuptools import setup
from setuptools import find_packages


with open("README.md", "r", encoding="utf-8") as fp:
    long_description = fp.read()

setup(
    name                 = "litescope",
    description          = "Small footprint and configurable embedded FPGA logic analyzer core",
    author               = "Florent Kermarrec",
    author_email         = "florent@enjoy-digital.fr",
    url                  = "http://enjoy-digital.fr",
    download_url         = "https://github.com/enjoy-digital/litescope",
    test_suite           = "test",
    license              = "BSD",
    python_requires      = "~=3.7",
    packages             = find_packages(exclude=("test*", "sim*", "doc*", "examples*")),
    include_package_data = True,
    long_description              = long_description,
    long_description_content_type = "text/markdown",
    version="2023.12",
    entry_points={
        "console_scripts": [
            "litescope_cli=litescope.software.litescope_cli:main",
        ],
    },
)
